#include <stdio.h>
#include <sys/times.h>
#include <sys/types.h>
#include <sys/file.h>
#include <errno.h>
#include "mex.h"
#include "intrfc.h"
#include "dapio.c"
#define SetBit12 (1 << 12) |
#define SetBit13 (1 << 13) |
#define SetBit14 (1 << 14) |
#define SetBit15 (1 << 15) |

void mexFunction(
   int nlhs, mxArray *plhs[],
   int nrhs, const mxArray *prhs[])
   {
   short FromDapBit2,FromDapBit1,FromDapBit0;
   short ToDapLow, ToDapHigh;
   short ToDapArray[3];
   double *NumIncrements, *ChannelSettings;
   int i,j;
   int total,BytesAvail;
   clock_t t;
   struct tms buf;
   char dapline[80];

    /* Redirect ctrl-c so that MEX file can close DAP channels
      before exiting. */
   mysig();

   /* Open handles to DAP text and binary communication pipes */
   if ((fdDapTxt=open("/dev/accel0",O_RDWR)) <= 0)
     { printf("Error opening accel0, errno=%d\n",errno); return; }
   if ((fdDapBin=open("/dev/accel1",O_RDWR)) <= 0)
     { printf("Error opening accel1, errno=%d\n",errno); return; }

   /* Flush communication channels. */
   DAPFlush(fdDapBin);
   DAPFlush(fdDapTxt);

   /* Create an array to return channel settings to MATLAB */
   plhs[0] = mxCreateDoubleMatrix(1,8,mxREAL);

   /* Set internal pointer to the new array */
   ChannelSettings = mxGetPr(plhs[0]);

   /* Get pointer to data from MATLAB */
   NumIncrements = mxGetPr(prhs[0]);

   for (i=0;i<8;i++){
     ToDapLow = 0;
     if (i / 4) { ToDapLow = SetBit12 ToDapLow;}
     if ((i % 4) / 2) { ToDapLow = SetBit13 ToDapLow;}
     if (i % 2) { ToDapLow = SetBit14 ToDapLow;}
     ToDapHigh = SetBit15 ToDapLow;
     ToDapArray[0] = ToDapArray[2] = ToDapLow;
     ToDapArray[1] = ToDapHigh;
     for (j=0;j<NumIncrements[i];j++){
       write(fdDapBin,ToDapArray,6);}
     ToDapArray[0] = ToDapArray[1] = ToDapArray[2] = ToDapLow;
     write(fdDapBin,ToDapArray,6);
 
     /* Pause 10ms while data is sent to DAP */
     t = times(&buf);
     while ((times(&buf)-t) < 1) {}

     /* Start DAP script to read channel setting */
     DAPSendLine(fdDapTxt,"start echreadd,echreadc\r");
 
     /* Wait for data and get it */
     while (DAPGetAvail(fdDapBin) < 6) {
       if ((times(&buf)-t) > 1000) {break;}}
 
     FromDapBit2 = FromDapBit1 = FromDapBit0 = 0;
     if (DAPGetAvail(fdDapBin) == 6) {
       read(fdDapBin,&FromDapBit2,2);
       read(fdDapBin,&FromDapBit1,2);
       read(fdDapBin,&FromDapBit0,2);}
 
     /* Stop DAP script.  Note that only echreadc */
     /* should be stopped since echreadd is already done. */
     DAPSendLine(fdDapTxt,"stop echreadc\r");

     ChannelSettings[i] = (double) FromDapBit0;
     ChannelSettings[i] += (double) 2*FromDapBit1;
     ChannelSettings[i] += (double) 4*FromDapBit2;

   }
   
   /* close handles */
   close(fdDapTxt);
   close(fdDapBin);

   /* Restore original ctrl-c handler. */
   restoresig();
   }








