function ec = ECDfault()
%ECDfault: returns eightchannel variable ec set to default values

%The channel_settings field stores the settings (0 through 7) of
%each of the eight amplifiers (A through H).
ec.channel_settings = zeros(1,8);

%The array_type field stores a number corresponding to
%which electrode array geometry is used.
%
% 1 = hexagonal array
% 2 = 25 micron spaced array
% 3 = TicTacToe array
ec.array_type = 2;

%The preamp_type field stores a number corresponding to
%which preamplifier is used.
%
% 1 = Version 1 Pre-amp (wire-wrapped, 4051 multiplexer)
% 2 = Version 2 Pre-amp (PC board, ADG408 multiplexer)
ec.preamp_type = 2;

%The stim_plus field stores a list of electrodes connected
%to the stimulator's positive terminal.
%The stim_minus field stores a list of electrodes connected
%to the stimulator's negative terminal.
%The numerical values stored in these fields are mapped as follows:
%
% 0 = recording ground (wire in bath)
% 1-8 = A0 through A7
% 9-16 = B0 through B7
% 17-24 = C0 through C7
% 25-32 = D0 through D7
% 33-40 = E0 through E7
% 41-48 = F0 through F7
% 49-56 = G0 through G7
% 57-64 = H0 through H7
%
%An empty vector indicates that the terminal in question is
%not connected to the array or to ground.
ec.stim_plus = [];
ec.stim_minus = [];

