%ECstart: start eightchannel routines, initializing an ec structure if needed
%

% Initialize eightchannel parameter variable ec if it
% doesn't already exist.

if ~exist('ec')
  ECinit;
else
  if ~ECistrct(ec)
    errordlg(['EC: global variable ec is not of type ec. ' ...
              'Over-writing.']);
    ECinit;
  end
end

% Check channel_settings field
if sum(ec.channel_settings < 0) | sum(ec.channel_settings > 8) | ...
size(ec.channel_settings,1) ~= 1 | size(ec.channel_settings,2) ~= 8
  errordlg(['EC: invalid channel_settings. ' ...
            'Setting all channels to zero.']);
  ec.channel_settings = zeros(1,8);
end

% Check array_type field
if (ec.array_type < 1) | (ec.array_type > 3)
  errordlg(['EC: invalid array_type. ' ...
            'Setting array type to one (hexagonal).']);
  ec.array_type = 1;
end

% Check preamp_type field
if (ec.preamp_type < 1) | (ec.preamp_type > 2)
  errordlg(['EC: invalid preamp_type. ' ...
            'Setting preamp type to two (Version 2).']);
  ec.preamp_type = 2;
end

% Check stim_plus field
for i=1:size(ec.stim_plus,2)
  if ((ec.stim_plus(i) < 0) | (ec.stim_plus(i) > 64)) & ...
     (ec.stim_plus(i) ~= 201)
    errordlg(['EC: invalid values in stim_plus field. ' ...
              'Emptying stim_plus field (no connection).']);
    ec.stim_plus = [];
    break
  end
end

% Check stim_minus field
for i=1:size(ec.stim_minus,2)
  if ((ec.stim_minus(i) < 0) | (ec.stim_minus(i) > 64)) & ...
     (ec.stim_minus(i) ~= 201)
    errordlg(['EC: invalid values in stim_minus field. ' ...
              'Emptying stim_plus field (no connection).']);
    ec.stim_minus = [];
    break
  end
end

% Make sure stim_plus and stim_minus don't contain any of same values
if (size(ec.stim_plus,2) > 0) & (size(ec.stim_minus,2) > 0)
  if find(ec.stim_plus'*ones(1,size(ec.stim_minus,2)) == ...
          ones(size(ec.stim_plus,2),1)*ec.stim_minus)
    errordlg(['EC: stim_plus and stim_minus field have identical ' ...
              'value(s). Emptying both fields (no connection).']);
    ec.stim_minus = [];
    ec.stim_plus = [];
  end
end

% Create a new screen
ECscr;
drawnow,drawnow,drawnow


ECOnColor(1,1:3) = [1 1 1];  %for A electrodes
ECOnColor(2,1:3) = [1 1 1];  %for B electrodes
ECOnColor(3,1:3) = [1 0 0];  %for C electrodes
ECOnColor(4,1:3) = [1 .5 0]; %for D electrodes
ECOnColor(5,1:3) = [1 1 1];  %for E electrodes
ECOnColor(6,1:3) = [1 1 1];  %for F electrodes
ECOnColor(7,1:3) = [1 0 0];  %for G electrodes
ECOnColor(8,1:3) = [1 1 1];  %for H electrodes


% Update screen
DapRset
ECDapNit
ECDapStt
ec.channel_settings = ECDapRd(zeros(1,8));
ECDapStp
for i = 1:8
  EChandle = findobj('String',[char(i+64) num2str(ec.channel_settings(i))]);
  set(EChandle,'Color',ECOnColor(i,1:3))
end

%Add stimulator connection info.
for i = 1:size(ec.stim_plus,2)
  set(findobj('Tag', [char(floor(ec.stim_plus(i)/8)+65) ...
                      num2str(mod(ec.stim_plus(i),8)-1) 'Outline']), ...
      'Visible','on','FaceColor','k','EdgeColor','k')
end
for i = 1:size(ec.stim_minus,2)
  set(findobj('Tag', [char(floor(ec.stim_minus(i)/8)+65) ...
                      num2str(mod(ec.stim_minus(i),8)-1) 'Outline']), ...
      'Visible','on','FaceColor','w','EdgeColor','w')
end


clear i
clear ECOnColor
clear EChandle









