function newec = ECsw(oldec,action)
%ECsw: callback functions for changing eight channel amp settings

global ui;

EConcolor(1,1:3) = [1 1 1];  %for A electrodes
EConcolor(2,1:3) = [1 1 1];  %for B electrodes
EConcolor(3,1:3) = [1 0 0];  %for C electrodes
EConcolor(4,1:3) = [1 .5 0]; %for D electrodes
EConcolor(5,1:3) = [1 1 1];  %for E electrodes
EConcolor(6,1:3) = [1 1 1];  %for F electrodes
EConcolor(7,1:3) = [1 0 0];  %for G electrodes
EConcolor(8,1:3) = [1 1 1];  %for H electrodes

newec = oldec;

switch action

  case 'ecr'
    newec.channel_settings = ECSet(round(8*unifrnd(0,1,1,8)));

  case 'ecz'
    newec.channel_settings = ECSet(zeros(1,8));

  case 'eci'
    ECDapStt;
    newec.channel_settings = ECDapRd(ones(1,8));
    ECDapStp;

  case 'refresh'
    newec = ECrefrsh(newec);

end

switch action(1)

  case {'A','B','C','D','E','F','G','H','Z'}
    switch ui.ecchange
  
      %Recording
      case 1
        if (strcmp(action(1),'Z'))
          break;
        end
        if ~(str2num(action(2)) == ...
             oldec.channel_settings(double(action(1))-64))
          set(findobj('String',action),'Color', ...
              EConcolor(double(action(1))-64,1:3));
          set(findobj('String',[action(1) num2str(oldec.channel_settings( ...
              double(action(1)-64)))]),'Color',[0 0 0]);
        end
        drawnow,drawnow,drawnow
        newec.channel_settings(double(action(1))-64) = str2num(action(2));
        ECDapStt
        ECDapRd(mod(newec.channel_settings-oldec.channel_settings,8));
        ECDapStp

      %Stimulator: +
      case 2
        EName = get(gcbo,'Tag');
        EName = EName(1:2);
        ENumber = (double(EName(1))-65)*8 + str2num(EName(2)) + 1;
        if isempty(newec.stim_plus) | ~sum(find(newec.stim_plus == ENumber))
          newec.stim_plus = [ENumber newec.stim_plus];
          set(findobj('Tag', [EName 'Outline']), ...
              'Visible','on','FaceColor','k','EdgeColor','k')

        %Move clicked electrode to front of list if its already connected.
        elseif ~isempty(newec.stim_plus) & ...
               sum(find(newec.stim_plus == ENumber))
          i = find(newec.stim_plus ~= ENumber);
          newec.stim_plus = [ENumber newec.stim_plus(i)];
        end

        %Remove from stim_minus field if applicable
        if ~isempty(newec.stim_minus) & sum(find(newec.stim_minus == ENumber))
          newec.stim_minus(find(newec.stim_minus == ENumber)) = -1;
          newec.stim_minus = newec.stim_minus(find(newec.stim_minus >= 0));
        end

        %If parallel connections not enabled, remove other connections
        %to stimulator positive terminal.
        if ~get(findobj('Tag','EnableParallel'),'Value')
          if (size(newec.stim_plus,2) > 1)
            for i = 2:size(newec.stim_plus,2)
              ENumber = newec.stim_plus(i);
              EName = [char(65+floor((ENumber-1)/8)) ...
                       num2str(mod((ENumber-1),8))];
              set(findobj('Tag', [EName 'Outline']),'Visible','off')
            end
            newec.stim_plus = newec.stim_plus(1);
          end
        end

      %Stimulator: -
      case 3
        EName = get(gcbo,'Tag');
        EName = EName(1:2);
        ENumber = (double(EName(1))-65)*8 + str2num(EName(2)) + 1;
        if isempty(newec.stim_minus) | ~sum(find(newec.stim_minus == ENumber))
          newec.stim_minus = [ENumber newec.stim_minus];
          set(findobj('Tag', [EName 'Outline']), ...
              'Visible','on','FaceColor','w','EdgeColor','w')

        %Move clicked electrode to front of list if its already connected.
        elseif ~isempty(newec.stim_minus) & ...
               sum(find(newec.stim_minus == ENumber))
          i = find(newec.stim_minus ~= ENumber);
          newec.stim_minus = [ENumber newec.stim_minus(i)];
        end
      
        %Remove from stim_plus field if applicable
        if ~isempty(newec.stim_plus) & sum(find(newec.stim_plus == ENumber))
          newec.stim_plus(find(newec.stim_plus == ENumber)) = -1;
          newec.stim_plus = newec.stim_plus(find(newec.stim_plus >= 0));
        end

        %If parallel connections not enabled, remove other connections
        %to stimulator negative terminal.
        if ~get(findobj('Tag','EnableParallel'),'Value')
          if (size(newec.stim_minus,2) > 1)
            for i = 2:size(newec.stim_minus,2)
              ENumber = newec.stim_minus(i);
              EName = [char(65+floor((ENumber-1)/8)) ...
                       num2str(mod((ENumber-1),8))];
              set(findobj('Tag', [EName 'Outline']),'Visible','off')
            end
            newec.stim_minus = newec.stim_minus(1);
          end
        end


      %Stimulator: N/C
      case 4
        EName = get(gcbo,'Tag');
        EName = EName(1:2);
        ENumber = (double(EName(1))-65)*8 + str2num(EName(2)) + 1;
        if ~isempty(newec.stim_plus) & find(newec.stim_plus == ENumber)
          newec.stim_plus(find(newec.stim_plus == ENumber)) = -1;
          newec.stim_plus = newec.stim_plus(find(newec.stim_plus >= 0));
          set(findobj('Tag', [EName 'Outline']), ...
              'Visible','off')
        end
        if ~isempty(newec.stim_minus) & find(newec.stim_minus == ENumber)
          newec.stim_minus(find(newec.stim_minus == ENumber)) = -1;
          newec.stim_minus = newec.stim_minus(find(newec.stim_minus >= 0));
          set(findobj('Tag', [EName 'Outline']), ...
              'Visible','off')
        end
   end
end


% If calling from shortrec screen, update it
if strcmp(get(gcf,'Tag'),'ShortRec')
  for i = 1:8
    set(findobj('Tag',[char(64+i) 'Setting']),'String', ...
      [char(64+i) num2str(newec.channel_settings(i))]);
    end
end











