#include <stdio.h>
#include <sys/times.h>
#include <sys/types.h>
#include <sys/file.h>
#include <errno.h>
#include "mex.h"
#include "intrfc.h"
#include "dapio.c"

void mexFunction(
   int nlhs, mxArray *plhs[],
   int nrhs, const mxArray *prhs[])
   {
   double *InData;            /* data comes in from matlab */
   short OutData[502];        /* and goes out to board */
   short DapData[5];
   int i,j;
   struct tms buf;
   clock_t t;
   unsigned int SpikeTime;
   unsigned int NumChanSpikes[9];
   unsigned int SpikeCount;
   double *ToMatlab;
   char DapCmd[80];
   int mrows,ncols;

   /* Check for proper number of arguments */
   if (nrhs != 1) {
      mexErrMsgTxt("PSTH2 usage: PSTH2([1 x 8 vector of thresholds])");
   }

   /* The input must be a noncomplex 1 by 8 vector */
   mrows = mxGetM(prhs[0]);
   ncols = mxGetN(prhs[0]);
   if ( !mxIsDouble(prhs[0]) || mxIsComplex(prhs[0]) ||
        !(mrows==1 && ncols==8) ) {
      mexErrMsgTxt("PSTH2 usage: PSTH2([1 x 8 vector of thresholds])");
   }

   /* Redirect ctrl-c so that MEX file can close DAP channels
      before exiting. */
   mysig();

   SpikeCount = 0;
   for (i=0;i<9;i++)
     NumChanSpikes[i] = 0;

   /* Create an array to return spike data to MATLAB */
   plhs[0] = mxCreateDoubleMatrix(3*MAX_SPIKES_PER_CHANNEL,9,mxREAL);
   ToMatlab = mxGetPr(plhs[0]);

   /* Download custom command from matlab*/
   /*   system("/usr/src/linux/drivers/dap/comload /dosc/andrew/dap/getspike.bin -s1000");*/
   
   /* Open handles to DAP text and binary communication pipes */
   if ((fdDapTxt=open("/dev/accel0",O_RDWR)) <= 0)
     { printf("Error opening accel0, errno=%d\n",errno); return; }
   if ((fdDapBin=open("/dev/accel1",O_RDWR)) <= 0)
     { printf("Error opening accel1, errno=%d\n",errno); return; }

   /* Stop DAP processing and flush old data still in com pipes */
   DAPSendLine(fdDapTxt,"\rRESET\r");
   DAPFlush(fdDapTxt);
   DAPFlush(fdDapBin);

   /* Send DAP scripts to the board */
   DAPSendFile(fdDapTxt,"/home/andrew/matlab/intrfc/dap/opstim2.dap");
   DAPSendFile(fdDapTxt,"/home/andrew/matlab/intrfc/dap/psth2.dap");

   /* Wait a brief interval */
   t = times(&buf);
   while ( (times(&buf)-t) < 10 );

   /* Assign thresholds to values provided by user */
   InData = mxGetPr(prhs[0]);
   sprintf(DapCmd,"LET THR0=%d\r",(short) InData[0]);
   DAPSendLine(fdDapTxt,DapCmd);
   sprintf(DapCmd,"LET THR1=%d\r",(short) InData[1]);
   DAPSendLine(fdDapTxt,DapCmd);
   sprintf(DapCmd,"LET THR2=%d\r",(short) InData[2]);
   DAPSendLine(fdDapTxt,DapCmd);
   sprintf(DapCmd,"LET THR3=%d\r",(short) InData[3]);
   DAPSendLine(fdDapTxt,DapCmd);
   sprintf(DapCmd,"LET THR4=%d\r",(short) InData[4]);
   DAPSendLine(fdDapTxt,DapCmd);
   sprintf(DapCmd,"LET THR5=%d\r",(short) InData[5]);
   DAPSendLine(fdDapTxt,DapCmd);
   sprintf(DapCmd,"LET THR6=%d\r",(short) InData[6]);
   DAPSendLine(fdDapTxt,DapCmd);
   sprintf(DapCmd,"LET THR7=%d\r",(short) InData[7]);
   DAPSendLine(fdDapTxt,DapCmd);

   /* Wait a brief interval */
   t = times(&buf);
   while ( (times(&buf)-t) < 10 );

   /* Start DAP script */
   DAPSendLine(fdDapTxt,"start pstha,psthb,ledstim2a,ledstim2b\r");

   /* copy led waveform into output matrix */
   OutData[0] = OutData[501] = 0;
   for (i=1; i < 501; i++) {
     OutData[i] = 16384;}

   for (j=0; j< 1; j++) {

     /* write to dap board via binary channel */
     write(fdDapBin,OutData,1004);

     /* Wait 11 sec.  NB: Interval starts at start of LED ON */
     t = times(&buf);
     while ( (times(&buf)-t) < 1100 ) {
         if (DAPGetAvail(fdDapBin) >= 10) {
         read(fdDapBin,DapData,10);
         if (NumChanSpikes[DapData[0]] < MAX_SPIKES_PER_CHANNEL) {
           i = 3 *
           ((MAX_SPIKES_PER_CHANNEL*DapData[0])+NumChanSpikes[DapData[0]]);
           SpikeTime = (unsigned int) ((unsigned short) DapData[2]) << 16;
           SpikeTime = SpikeTime + (unsigned int) ((unsigned short) DapData[1]);
           ToMatlab[i] = (double) SpikeTime;
           ToMatlab[i+1] = (double) DapData[3];
           ToMatlab[i+2] = (double) DapData[4];
           SpikeCount++;
           NumChanSpikes[DapData[0]]++;}}
     }
   }

   /* Wait a brief interval */
   t = times(&buf);
   while ( (times(&buf)-t) < 10 );

   /* close handles */
   close(fdDapTxt);
   close(fdDapBin);

   /* Restore original ctrl-c handler. */
   restoresig();

   }








