function thr = RTGetTh()
%RTGetTh = get threshold for RT screen
%Use negative-valued pulse.

global rt;

str1 = get(findobj('Tag','RTSupRatio'),'String');
str2 = get(findobj('Tag','RTThrRatio'),'String');
str3 = get(findobj('Tag','RTSubRatio'),'String');

if strcmp(str1(2),'/')
  num1 = str2num(str1(1));
else
  num1 = str2num(str1(1:2));
end

if strcmp(str2(2),'/')
  num2 = str2num(str2(1));
else
  num2 = str2num(str2(1:2));
end

if strcmp(str3(2),'/')
  num3 = str2num(str3(1));
else
  num3 = str2num(str3(1:2));
end

% Get the three voltage levels (for cathodic pulses) from
% the rt variable.

sup = (rt.suptp.full_scale/32768) * ...
      min(rt.suptp.pulse1_height,rt.suptp.pulse2_height);
mid = (rt.tp.full_scale/32768) * ...
      min(rt.tp.pulse1_height,rt.tp.pulse2_height);
sub = (rt.subtp.full_scale/32768) * ...
      min(rt.subtp.pulse1_height,rt.subtp.pulse2_height);

% If any of the num's is 5, corresponding value is threshold
if (num1 == 5)
  thr = sup;
  return;
end
if (num2 == 5)
  thr = mid;
  return;
end
if (num3 == 5)
  thr = sub;
  return;
end

% Otherwise, interpolate between a pair with num < 5 and num > 5.
if (num1 > 5) & (num2 < 5)
  thr = thinterp(sup,num1,mid,num2);
  return;
end
if (num2 > 5) & (num3 < 5)
  thr = thinterp(mid,num2,sub,num3);
  return;
end

%Return a zero if none of the above applies
thr = 0;

