function RTPltDat

%This function uses a simple algorithm for detecting spikes.
%If more than 10 sample points are found inside the box bounded
%by the four screen cursors, assume a spike has occurred.

global rt;
global sr;

%Experimental 3/29/99: use rt.threshtp instead of global tp.
%Makes it easier to use RTPltDat for browsing.
%global tp;
tp = rt.tp;

%For use in browse routines, assign sr to default if it doesn't
%exist already.
%Won't necessarily reflect measurement conditions.
%Fixed 3/29/99.
if isempty(sr)
  sr = SRDfault;
end
if isempty(tp)
  tp = TPDfault;
end

% Define some variables for plotting

t = -1:.01:.01*899;
m = (sr.full_scale/32768);
stim_width = ((rt.tp.pulse1_delay+rt.tp.pulse1_width+ ...
         rt.tp.pulse2_delay+rt.tp.pulse2_width)*rt.tp.update_interval*.001);

width = stim_width+2;


% Plot to 'Current'; use measurement of threshold current
axes(findobj('Tag','RTCurrent'));
cla;
hold on;

%compute offset from first 50 samples
cm_offset = mean(rt.threshmons(2,1:50));

% samples are taken every 10microseconds, starting 1ms before stimulus onset
cmtime = (0:.01:.01*999) - 1;

switch sr.cm_jumpers(2)
  case 0
    VperUA = 2;
  case 1
    VperUA = .2;
  case else
    VperUA = .2;
end

m2 = m/VperUA;
plot(cmtime,m2*(rt.threshmons(2,:) - (ones(1,1000)*cm_offset)));
inc = abs(tp.pulse1_height-tp.pulse2_height)*.2;
axis([-.5 width (m2*(min(tp.pulse1_height,tp.pulse2_height)-inc)) ...
(m2*(max(tp.pulse1_height,tp.pulse2_height)+inc))]);
ylabel('Measured uA');

% Overlay ideal waveform
t2 = 0:.01:(.01*(tp.num_samples-1));
switch tp.rt
  case 1
    MicroampsPerVolt = .2
  case 2
    MicroampsPerVolt = 2;
  case 3
    MicroampsPerVolt = 20;
  case else
    MicroampsPerVolt = 2;
end

exact = TPPlsOut(tp)*(tp.full_scale/32768)*MicroampsPerVolt;
hold on;
plot(t2,exact,'Color','r','LineStyle','--');
hold off;


% Plot to 'Supra'

axes(findobj('Tag','RTSupra'));
cla;
hold on;
DetectedSpikes = 0;
for h = 1:10
  plot(t,m*rt.supresp(h,:));  
  x = find((t > min(rt.lft,rt.rgt)) & (t < max(rt.lft,rt.rgt)));
  y = find ( (m*rt.supresp(h,x) > min(rt.top,rt.bot)) & ...
             (m*rt.supresp(h,x) < max(rt.top,rt.bot)) );
  if ( size(y,2) > 10 )
     DetectedSpikes = DetectedSpikes + 1;
  end
  if get(findobj('Tag','RTShowSample'),'Value')
    plot(t,m*rt.sample,'Color',[0 1 0],'LineWidth',2);
  end
end
hold off;
ymin = str2num(get(findobj('Tag','RTymin'),'String'));
ymax = str2num(get(findobj('Tag','RTymax'),'String'));
axis([0 width ymin ymax]);
h1Str = sprintf('%.3f',(rt.suptp.pulse1_height/32768)*rt.tp.full_scale);
h2Str = sprintf('%.3f',(rt.suptp.pulse2_height/32768)*rt.tp.full_scale);
title(['h1=' h1Str ',h2=' h2Str]);
set(findobj('Tag','RTSupRatio'),'String',[num2str(DetectedSpikes) '/10']);

% Plot to 'Threshold'

axes(findobj('Tag','RTThreshold'));
cla;
hold on;
DetectedSpikes = 0;
for h = 1:10
  plot(t,m*rt.threshresp(h,:));  
  x = find((t > min(rt.lft,rt.rgt)) & (t < max(rt.lft,rt.rgt)));
  y = find ( (m*rt.threshresp(h,x) > min(rt.top,rt.bot)) & ...
             (m*rt.threshresp(h,x) < max(rt.top,rt.bot)) );
  if ( size(y,2) > 10 )
     DetectedSpikes = DetectedSpikes + 1;
  end
  if get(findobj('Tag','RTShowSample'),'Value')
    plot(t,m*rt.sample,'Color',[0 1 0],'LineWidth',2);
  end
end
hold off;
ymin = str2num(get(findobj('Tag','RTymin'),'String'));
ymax = str2num(get(findobj('Tag','RTymax'),'String'));
axis([0 width ymin ymax]);
h1Str = sprintf('%.3f',(rt.tp.pulse1_height/32768)*rt.tp.full_scale);
h2Str = sprintf('%.3f',(rt.tp.pulse2_height/32768)*rt.tp.full_scale);
title(['h1=' h1Str ',h2=' h2Str]);
set(findobj('Tag','RTThrRatio'),'String',[num2str(DetectedSpikes) '/10']);

% Plot to 'Sub'

axes(findobj('Tag','RTSub'));
cla;
hold on;
DetectedSpikes = 0;
for h = 1:10
  plot(t,m*rt.subresp(h,:));  
  x = find((t > min(rt.lft,rt.rgt)) & (t < max(rt.lft,rt.rgt)));
  y = find ( (m*rt.subresp(h,x) > min(rt.top,rt.bot)) & ...
             (m*rt.subresp(h,x) < max(rt.top,rt.bot)) );
  if ( size(y,2) > 10 )
     DetectedSpikes = DetectedSpikes + 1;
  end
  if get(findobj('Tag','RTShowSample'),'Value')
    plot(t,m*rt.sample,'Color',[0 1 0],'LineWidth',2);
  end
end
hold off;
ymin = str2num(get(findobj('Tag','RTymin'),'String'));
ymax = str2num(get(findobj('Tag','RTymax'),'String'));
axis([0 width ymin ymax]);
h1Str = sprintf('%.3f',(rt.subtp.pulse1_height/32768)*rt.tp.full_scale);
h2Str = sprintf('%.3f',(rt.subtp.pulse2_height/32768)*rt.tp.full_scale);
title(['h1=' h1Str ',h2=' h2Str]);
set(findobj('Tag','RTSubRatio'),'String',[num2str(DetectedSpikes) '/10']);

% Update RTelectrode text box
set(findobj('Tag','RTelectrode'),'String', ['Recorded from: ' rt.ename]);

% Update SaveAs button
set(findobj('Tag','RTSaveAs'),'String',UIFileName);

% Draw cursors
RTDrawCurs;

% Enable save buttons
set(findobj('Tag','RTSave'),'Enable','on');
set(findobj('Tag','RTSaveAs'),'Enable','on');

% Compute threshold
thStr = sprintf('%.3f',RTGetTh);
set(findobj('Tag','RTThreshStr'),'String',thStr);

















