function RTSttStp()

global rt;
global tp;

%Disable start button
set(findobj('Tag','RTStart'),'Enable','off');
drawnow;

% Reset the DAP board and load it
% with the relevant routines.
DapRset;
TPDapNit;
RTDapNit;
ECDapNit;

% Tell Dap to wait for stimulation waveform
% Record from channel indicated on popup menu on RecordThresh screen.
ChannelName = char(get(findobj('Tag','RTChannel'),'Value')+96);
DapLine = ['start twplsb,twplsa,recthrsh' ChannelName ',recthrshz'];
DapSndLn(DapLine);

% Quick pause while configuring Dap
tic
while toc < .1
end

% Determine sizes for subthreshold and suprathreshold stimuli
[rt.subtp,rt.suptp] = RTSubSup(tp);
rt.tp = tp;

% Use vector StimOrder to determine height of stimulus to be
% applied on a particular round.
% 
%     mod(StimOrder(i),3) == 0   --->  supra-threshold
%     mod(StimOrder(i),3) == 1   --->  threshold
%     mod(StimOrder(i),3) == 2   --->  sub-threshold
%StimOrder = [(0:3:27) (1:3:28) (2:3:29)];
StimOrder = randperm(30);

% These counters keep track of how many of each type of
% stimulus have been applied.
SubCount = 0;
ThreshCount = 0;
SupCount = 0;

% Apply stimuli using StimOrder vector
for i = 1:size(StimOrder,2)
  switch mod(StimOrder(i),3)

    case 0
      SupCount = SupCount+1;
      TPDapSnd(reshape([TPTrgOut(rt.suptp)'; TPPlsOut(rt.suptp)'], ...
               rt.suptp.num_samples*2,1));
      rtdata = RTDapRd;
      rt.supresp(SupCount,1:size(rtdata,2)) = rtdata(3,:);
      rt.suptstamp(SupCount,1:size(datestr(now,0),2)) = datestr(now,0);
      if (SupCount == 1)  %Store only one record of monitor data
        rt.supmons = rtdata(1:2,:);
      end

    case 1
      ThreshCount = ThreshCount+1;
      TPDapSnd(reshape([TPTrgOut(rt.tp)'; TPPlsOut(rt.tp)'], ...
               rt.tp.num_samples*2,1));
      rtdata = RTDapRd;
      rt.threshresp(ThreshCount,1:size(rtdata,2)) = rtdata(3,:);
      rt.threshtstamp(ThreshCount,1:size(datestr(now,0),2)) = datestr(now,0);
      if (ThreshCount == 1)  %Store only one record of monitor data
        rt.threshmons = rtdata(1:2,:);
      end

    case 2
      SubCount = SubCount+1;
      TPDapSnd(reshape([TPTrgOut(rt.subtp)'; TPPlsOut(rt.subtp)'], ...
               rt.subtp.num_samples*2,1));
      rtdata = RTDapRd;
      rt.subresp(SubCount,1:size(rtdata,2)) = rtdata(3,:);
      rt.subtstamp(SubCount,1:size(datestr(now,0),2)) = datestr(now,0);
      if (SubCount == 1)  %Store only one record of monitor data
        rt.submons = rtdata(1:2,:);
      end

  end

  tic
  while toc < .1
  end

end

% Stop Dap routines after short pause
tic
while toc < .1
end
DapLine = ['stop twplsa,twplsb,recthrsh' ChannelName ',recthrshz'];
DapSndLn(DapLine);

% Update recording electrode name
ECDapStt;
settings = ECDapRd(zeros(1,8));
ECDapStp;
ChannelNum = get(findobj('Tag','RTChannel'),'Value');
ChannelName = char(ChannelNum+64);
ElectrodeName = [ChannelName num2str(settings(ChannelNum))];
rt.ename = ElectrodeName;

% Plot the data
RTPltDat;

%Enable start button
set(findobj('Tag','RTStart'),'Enable','on');
drawnow;
