function [x,y,reps] = SCcorr(filename,Window)
%SCcorr: find correlated spikes, occurring in SpikeVector within
%Window samples of one another.

%Load SpikeVector
load(filename)

%Extract channel settings from filename
if findstr('mat',filename)
  SettingStr = filename((size(filename,2)-11):(size(filename,2)-4));
else
  SettingStr = filename((size(filename,2)-7):(size(filename,2)));
end

for i = 1:8
  channel_settings(i) = str2num(SettingStr(i));
end

%Find arrival times and sort them chronologically
[y,i] = sort(SpikeVector(2:22:size(SpikeVector,2)));

%Trim leading zeros
i = i(find(y));
y = y(find(y));

%Compute differences
n = size(y,2);
diffs = abs(y(2:n) - y(1:(n-1)));

%Find indices, into sorted matrix, of spikes occurring within
%Window of one another.
k = find(diffs < Window);

%Find channels for each correlated pair

%For each element km of the vector k, closely spiking pairs are at
%indices i[km] and i[km+1].

%Put the r channel pairs in an rx2 matrix
ChannelPairs = [SpikeVector(1+(22*(i(k)-1)))' ...
               SpikeVector(1+(22*(i(k+1)-1)))'];


%Now convert to alphanumeric channel pairs
acp1 = '';
acp2 = '';
for m = 1:size(ChannelPairs,1)
     acp1 = strvcat(acp1,[char(ChannelPairs(m,1)+65) ...
       num2str(channel_settings(ChannelPairs(m,1)+1))]);
     acp2 = strvcat(acp2,[char(ChannelPairs(m,2)+65) ...
       num2str(channel_settings(ChannelPairs(m,2)+1))]);

     % make acp1 value always have lower alphabetical value
     if double(acp1(m,1)) > double(acp2(m,1))
       TempStr = acp2(m,:);
       acp2(m,:) = acp1(m,:);
       acp1(m,:) = TempStr;
     end

end

% sort by alphabetical value, using acp1 first, then acp2
[dummy,index] = sortrows([acp1 acp2]);
acp1 = acp1(index,:);
acp2 = acp2(index,:);

% Pack output arrays if they're not empty
if ~isempty(find(acp1))
  reps = 1;
  x = acp1(1,:);
  y = acp2(1,:);
  for i = 2:size(acp1,1)
    if strcmp(x(size(x,1),:),acp1(i,:))
       if strcmp(y(size(y,1),:),acp2(i,:))
          reps(size(reps,1)) = reps(size(reps,1)) + 1;
       else
          x = strvcat(x,acp1(i,:));
          y = strvcat(y,acp2(i,:));
          reps = [reps; 1];
       end
    else
      x = strvcat(x,acp1(i,:));
      y = strvcat(y,acp2(i,:));
      reps = [reps; 1];
    end

  end

else

  x = '';
  y = '';
  reps = 0;

end





