function sr = SRDfault()
%SRDfault: returns shortrec variable sr set to default values

% The datestr field holds a string which gives the date
% and time that the data in the nr_data and cm_data fields (below)
% were collected.
sr.datestr = datestr(now,0);

% The nr_sample_interval field is set equal to the number of
% microseconds between subsequent samples of an
% analog input channel used to record nerve responses.
% THIS VALUE SHOULD BE CHECKED AGAINST THE SAMPLE
% INTERVAL SPECIFIED IN shrtrecT.dap OR shrtrecU.dap.
sr.nr_sample_interval = 49.5;

% The nr_num_samples field is set equal to the number
% of samples read from each analog input channel used to
% record nerve responses.
% THIS VALUE SHOULD BE CHECKED AGAINST THE SAMPLE
% INTERVAL SPECIFIED IN shrtrecT.dap OR shrtrecU.dap.
sr.nr_num_samples = 1000;

% The nr_data field is an 8xnr_num_samples matrix holding
% the data from each of the 8 channels.  The data for a
% single channel is read along a single row.
sr.nr_data = zeros(8,sr.nr_num_samples);

% The cm_sample_interval field is set equal to the number of
% microseconds between subsequent samples of an
% analog input channel used to record from the current monitors.
% THIS VALUE SHOULD BE CHECKED AGAINST THE SAMPLE
% INTERVAL SPECIFIED IN shrtrecT.dap OR shrtrecU.dap.
sr.cm_sample_interval = 4.5;

% The cm_num_samples field is set equal to the number
% of samples read from each analog input channeld used to
% record from the current monitors;
% THIS VALUE SHOULD BE CHECKED AGAINST THE SAMPLE
% INTERVAL SPECIFIED IN shrtrecT.dap OR shrtrecU.dap.
sr.cm_num_samples = 671;

% The cm_data field is a 2xcm_num_samples matrix holding
% the data from each of the 2 monitors.  The data for a
% single monior is read along a single row.
sr.cm_data = zeros(sr.cm_num_samples,2);

% The cm_offsets field is a 1x2 vector holding
% the DC offsets measured from the current monitors.
sr.cm_offsets = zeros(1,2);

% The cm_jumpers field is a 1x2 vector holding
% a boolean telling whether or not the monitor's
% /10 are on or off.  cm_jumpers(1) is for monitor 1,
% and cm_jumpers(2) is for monitor 2.  A zero value
% indicates that the jumper is OFF, and a value of 1
% indicates that the jumper is ON.
sr.cm_jumpers = [0 1];

% The full_scale field is set to the full-scale voltage
% of the analog-to-digital converters on the DAP board.
% The ADC full-scale voltage, which may be one of several
% pre-set values, is set with jumpers on the board itself.
% These routines assume that the ADC has been set for
% biphasic or (positive and negative voltage) operation,
% as opposed to "single-supply" operation.
sr.full_scale = 5;

% The num_recs field holds the number of rounds of
% recording to be performed upon pressing the
% start button (within the shortrec environment).
% This field is set to a negative number for an
% unlimited number of rounds of recording.
sr.num_recs = 1;

% The stim_type field tells which type of stimulation should
% be applied in preparation for recording.
%        Value            Stimulation Type
%        -----            ----------------
%          1                  None
%          2                  Electric
%          3                  Optic
sr.stim_type = 1;
