%SRstart: start shortrec routines, initializing an sr structure if needed.
%
% Initialize shortrec parameter variable sr if it
% doesn't already exist, check values in the fields
% of sr to make sure they are valid, create shortrec screen
% and update it to reflect parameter values in sr.
% Also, reset DAP board and download routines used by sr screen.

% Initialize global shortrec parameter variable sr
% if it doesn't already exist.

if ~exist('sr')
  SRinit;
else
  if ~SRistrct(sr)
    errordlg(['SR: global variable sr is not of type sr. ' ...
              'Over-writing.']);
    SRinit;
  end
end

% Check values in the fields of sr to make sure they
% are valid.

if sr.nr_sample_interval <= 0
  errordlg(['SR: invalid nr_sample_interval. ' ...
            'Setting to 49.5 microseconds. ' ...
            'Check this value against that specified ' ...
            'in shrtrecT.dap or shrtrecU.dap.']);
  sr.nr_sample_interval = 49.5;
end

if sr.nr_num_samples <= 0
  errordlg(['SR: invalid nr_num_samples.' ...
            'Setting to 1000. ' ...
            'Check this value against that specified ' ...
            'in shrtrecT.dap or shrtrecU.dap.']);
  sr.nr_num_samples = 1000;
end

if (size(sr.nr_data,1) ~= 8) | (size(sr.nr_data,2) ~= sr.nr_num_samples)
  errordlg(['SR: nr_data is wrong size.' ...
            'Setting to 8 x ' num2str(sr.nr_num_samples) '.']);
  sr.nr_data = zeros(8,sr.nr_num_samples);
end

if sr.cm_sample_interval <= 0
  errordlg(['SR: invalid cm_sample_interval. ' ...
            'Setting to 4.5 microseconds. ' ...
            'Check this value against that specified ' ...
            'in shrtrecT.dap or shrtrecU.dap.']);
  sr.cm_sample_interval = 4.5;
end

if sr.cm_num_samples <= 0
  errordlg(['SR: invalid cm_num_samples.' ...
            'Setting to 671. ' ...
            'Check this value against that specified ' ...
            'in shrtrecT.dap or shrtrecU.dap.']);
  sr.cm_num_samples = 671;
end

if (size(sr.cm_data,1) ~= sr.cm_num_samples) | (size(sr.cm_data,2) ~= 2)
  errordlg(['SR: cm_data is wrong size.' ...
            'Setting to ' num2str(sr.cm_num_samples) ' x 2.']);
  sr.cm_data = zeros(sr.cm_num_samples,2);
end

if (size(sr.cm_offsets,1) ~= 1) | (size(sr.cm_offsets,2) ~= 2)
  errordlg(['SR: cm_offsets is wrong size.' ...
            'Setting to 1 x 2']);
  sr.cm_offsets = zeros(1,2);
end

if (size(sr.cm_jumpers,1) ~= 1) | (size(sr.cm_jumpers,2) ~= 2)
  errordlg(['SR: cm_jumpers is wrong size.' ...
            'Setting to 1 x 2']);
  sr.cm_jumpers = zeros(1,2);
end

if ~ismember(sr.full_scale,[2.5 5 10])
  errordlg(['SR: Bad full_scale value.' ...
            'Setting to 5.']);
  sr.full_scale = 5;
end

if sr.num_recs < 0
  errordlg(['SR: Bad num_recs value.' ...
            'Setting to 1.']);
  sr.num_recs = 1;
end

if ~ismember(sr.stim_type,[1 2 3])
  errordlg(['SR: Bad stim_type value.' ...
            'Setting to 1 (None).']);
  sr.stim_type = 1;
end

% Create shortrec screen and update it to reflect parameter
% values in sr.

if isempty(findobj('Tag','ShortRec'))
  SRscr;
  intrmenu;
end

% Reset DAP board and download scripts used by this screen
DapRset
TPDapNit
SRDapNit
ECDapNit

% Read eight channel amplifier settings and update screen
ECDapStt
ec.channel_settings = ECDapRd(zeros(1,8));
for i = 1:8
   set(findobj('Tag',[char(64+i) 'Setting']),'String', ...
     [char(64+i) num2str(ec.channel_settings(i))]);
end

    % Close channel-setting-reading routine.
    ECDapStp
switch sign(sr.num_recs)

  % finite number of rounds of recording
  case {0,1}
      set(findobj('Tag','count'),'Visible','on')

  % infinite number of rounds of stimulation
  case -1
    set(findobj('Tag','count'),'Visible','off')

end

% Update popup menus
set(findobj('Tag','StimType'),'Value',sr.stim_type)
set(findobj('Tag','Mon1Jumper'),'Value',sr.cm_jumpers(1)+1)
set(findobj('Tag','Mon2Jumper'),'Value',sr.cm_jumpers(2)+1)

% Update stimulation waveform
TPNwTxt(tp,101);
TPNwTxt(tp,102);

% Plot Data to screen
nrtime = (0:sr.nr_sample_interval: ...
  (sr.nr_num_samples-1)*sr.nr_sample_interval)/1000;
for i=1:8
  axes(findobj('Tag',[char(64+i) 'Data']));
  plot(nrtime,(100*sr.full_scale/32768)*sr.nr_data(i,:));
  if i ~= 8
    set(gca,'XTick',[]);
  end
%   set(gca,'YTick',[]);
  set(gca,'Tag',[char(64+i) 'Data']);
end
xlabel('Time (ms)')
ylabel('Electrode Voltage (uV)')

% Plot only current monitor 2 data.  This monitor measures load
% current.  Current monitor 1 is now (8/25/97) used to measure
% load voltage.
axes(findobj('Tag','StimCurrent'));
cmtime = 0:sr.cm_sample_interval: ...
  (sr.cm_num_samples-1)*sr.cm_sample_interval;
plot(cmtime,sr.cm_data(:,2));
xlabel('Time (us)')
ylabel('Monitor Output (V)')
set(gca,'Tag','StimCurrent');
 
% Update screen text
SRNwTxt(sr,100)

