#include <stdio.h>
#include <sys/types.h>
#include <sys/file.h>
#include <errno.h>
#include "mex.h"
#include "intrfc.h"
#include "dapio.c"

void mexFunction(
   int nlhs, mxArray *plhs[],
   int nrhs, const mxArray *prhs[])
   {
   double *InData;            /* data comes in from matlab */
   short *OutData;        /* and goes out to board */
   int i;
   int m;
   int NumTransferred;

   /* Redirect ctrl-c so that MEX file can close DAP channels
      before exiting. */
   mysig();

   /* Open handles to DAP text and binary communication pipes */
   if ((fdDapTxt=open("/dev/accel0",O_RDWR)) <= 0)
     { printf("Error opening accel0, errno=%d\n",errno); return; }
   if ((fdDapBin=open("/dev/accel1",O_RDWR)) <= 0)
     { printf("Error opening accel1, errno=%d\n",errno); return; }

   /* get pointer to input data */
   InData = mxGetPr(prhs[0]);

   /* get size of input data */
   m = mxGetM(prhs[0]);
   
   /* create array for output data */
   OutData = mxCalloc(m,sizeof(short));
 
   /* copy dap data into output matrix, converting to type short */
   for (i=0; i < m; i++) {
     OutData[i] = (short) InData[i];}

   /* initialize number of values sent */
   NumTransferred = 0;

   /* write to dap board via binary channel */
   while (NumTransferred < m) {
     i = DAPPutAvail(fdDapBin);
     if ( (i/2) > (m-NumTransferred) ) {
       i = 2*(m-NumTransferred); }
     write(fdDapBin,&OutData[NumTransferred],i);
     NumTransferred += (i/2); }

   /* close handles */
   close(fdDapTxt);
   close(fdDapBin);

   /* Restore original ctrl-c handler. */
   restoresig();
   }








