function [newtp,err] = TPLckHts(oldtp,action)
%TPLckHts: perform operations on heights of a shape-locked waveform

newtp = oldtp;
err = 0;

% Determine which of the two heights is the anchor, and
% assign anchor width and ratios accordingly.

if strcmp(action(1:2),'lk')
  AnchorStr = action(5:6);
else
  AnchorStr = action(1:2);
end

switch AnchorStr

  case 'h1'
    AnchorHeight = round(newtp.pulse1_height/16);

    % Ratio of pulse2_height to AnchorHeight
    Ratio = 1/newtp.h1h2_ratio;

  case 'h2'
    AnchorHeight = round(newtp.pulse2_height/16);  

    % Ratio of pulse1_height to AnchorHeight
    Ratio = newtp.h1h2_ratio;

end

% Make a vector of all possible heights for the anchor height.
CandidateHeights = (-32768/16):(32752/16);

% Err1 is the deviation of the "second height"
% from the closest integer, calulated from the ratio
% secondheight/AnchorHeight and the candidate
% anchor heights.
Err1 = abs( round(Ratio * CandidateHeights) - ...
                 (Ratio * CandidateHeights) );

% Find candidate heights which have acceptable errors
OkHeights = CandidateHeights(find(Err1 < newtp.height_tolerance));

% If no good heights were found, generate and error message
% and return the old waveform.
if isempty(OkHeights)
  err = 1;
  newtp = oldtp;
  h = errordlg(['Unable to find an acceptable combination of pulse ' ...
               'heights. ' ...
               'You might try decreasing the height of the waveform ' ...
               'or increasing height_tolerance.'],'TPPreset:','modal');
  figure(h)
  uiwait(h)
  return
end

% Find usable height which is closest to AnchorHeight
[dummy,ClosestHeight] = min(abs(AnchorHeight-OkHeights));


% Set new height based on instructions in action string
if strcmp(action(1:2),'lk')
  NewAnchorHeight = OkHeights(ClosestHeight);
else
  switch action

    case {'h1g','h2g'}
      if (ClosestHeight+1) <= size(OkHeights,2)
        NewAnchorHeight = OkHeights(ClosestHeight+1);
      else
        NewAnchorHeight = AnchorHeight;
      end

    case {'h1gg','h2gg'}
      if (ClosestHeight+10) <= size(OkHeights,2)
        NewAnchorHeight = OkHeights(ClosestHeight+10);
      else
        NewAnchorHeight = AnchorHeight;
      end

    case {'h1ggg','h2ggg'}
      if (ClosestHeight+100) <= size(OkHeights,2)
        NewAnchorHeight = OkHeights(ClosestHeight+100);
      else
        NewAnchorHeight = AnchorHeight;
      end

    case {'h1l','h2l'}
      if (ClosestHeight-1) > 0
        NewAnchorHeight = OkHeights(ClosestHeight-1);
      else
        NewAnchorHeight = AnchorHeight;
      end

    case {'h1ll','h2ll'}
      if (ClosestHeight-10) > 0
        NewAnchorHeight = OkHeights(ClosestHeight-10);
      else
        NewAnchorHeight = AnchorHeight;
      end

    case {'h1lll','h2lll'}
      if (ClosestHeight-100) > 0
        NewAnchorHeight = OkHeights(ClosestHeight-100);
      else
        NewAnchorHeight = AnchorHeight;
      end

  end

end


% Reassign pulse heights and delays

switch AnchorStr

  case 'h1'
    newtp.pulse1_height = NewAnchorHeight * 16;
    newtp.pulse2_height = round(NewAnchorHeight * Ratio * 16);

  case 'h2'
    newtp.pulse2_height = NewAnchorHeight * 16;  
    newtp.pulse1_height = round(NewAnchorHeight * Ratio * 16);

end

% Check to make sure that new pulse heights are within bounds

if (newtp.pulse1_height > 32752) | (newtp.pulse1_height < -32768) | ...
   (newtp.pulse2_height > 32752) | (newtp.pulse2_height < -32768)
  newtp = oldtp;
  if strcmp(action(1:2),'lk')
    err = 1;
    h = errordlg(['Unable to find an acceptable combination of pulse ' ...
                  'heights. ' ...
                  'You might try decreasing the height of the waveform ' ...
                  'or increasing height_tolerance.'],'TPPreset:','modal');
    figure(h)
    uiwait(h)
    return
  end
end

