#include <sys/times.h>
#include <stdio.h>
#include <sys/types.h>
#include <sys/file.h>
#include <errno.h>
#include <signal.h>
#include <unistd.h>
#include "mex.h"
#include "dapio.c"

/* global flag used by signal handling routine */
int stop_looping;
void loopstop(int);

void loopstop(int signum)
{
     (void) signal(SIGINT, loopstop);
     stop_looping = 1;
}

void mexFunction(
   int nlhs, mxArray *plhs[],
   int nrhs, const mxArray *prhs[])
   {
   double *InData;            /* data comes in from matlab */
   short OutData[602];        /* and goes out to board */
   int i;
   int fdDapTxt,fdDapBin;
   struct tms bufr;
   clock_t t1;
   void (* old_handler)(int);

   /* set handler for ctrl-c to loopstop, store old handler */
   old_handler = signal(SIGINT, loopstop);

   /* initialize global flag */
   stop_looping = 0;
   
   /* get pointer to input data */
   InData = mxGetPr(prhs[0]);

   /* copy dap data into output matrix, converting to type short */
   for (i=0; i < 602; i++) {
     OutData[i] = (short) InData[i];}

   /* Open handles to DAP text and binary communication pipes */
   if ((fdDapTxt=open("/dev/accel0",O_RDWR)) <= 0)
     { printf("Error opening accel0, errno=%d\n",errno); return; }
   if ((fdDapBin=open("/dev/accel1",O_RDWR)) <= 0)
     { printf("Error opening accel1, errno=%d\n",errno); return; }

   /* Stop DAP processing and flush old data still in com pipes */
   DAPSendLine(fdDapTxt,"\rRESET\r");
   DAPFlush(fdDapTxt);
   DAPFlush(fdDapBin);

   DAPSendFile(fdDapTxt,"twpls.dap");

   for(i=0;i<10;i++){
     /* write to dap board via binary channel */
     write(fdDapBin,OutData,1204);

     /* pause 100ms */
     t1 = times(&bufr);
     while((times(&bufr)-t1) < 100) {}

     if (stop_looping) { break; }
   }

   /* restore handler for ctrl-c */
   (void) signal(SIGINT, old_handler);

   DAPSendLine(fdDapTxt,"stop\r");

   /* close handles */
   close(fdDapTxt);
   close(fdDapBin);

   }








