%TPstart: start twopulse routines, initializing a tp structure if needed.
%
% Initialize twopulse parameter variable tp if it
% doesn't already exist, check values in the fields
% of tp to make sure they are valid, create twopulse
% screen if it doesn't exist and not running in silent
% mode, and update screen to reflect parameter values in tp.
% Also, reset DAP board and download routines used by tp screen.

% Initialize global twopulse parameter variable tp if it
% doesn't already exist.

if ~exist('tp')
  TPinit;
else
  if ~TPistrct(tp)
    errordlg(['TP: global variable tp is not of type tp. ' ...
              'Over-writing.']);
    TPinit;
  end
end

% Check values in the fields of tp to make sure they
% are valid.
if tp.update_interval <= 0
  errordlg(['TP: invalid update_interval. ' ...
            'Setting to 10 microseconds.']);
  tp.update_interval = 10;
end

tp.num_samples = round(tp.num_samples);
if tp.num_samples <= 0
  errordlg(['TP: invalid num_samples. ' ...
            'Setting to 301.']);
  tp.num_samples = 903;
end

if ~ismember(tp.full_scale,[2.5 5 10])
  errordlg(['TP: invalid full_scale. ' ...
            'Setting to 10.']);
  tp.full_scale = 10;
end

tp.pulse1_delay = round(tp.pulse1_delay);
if (tp.pulse1_delay < 0) | (tp.pulse1_delay >= tp.num_samples)
  errordlg(['TP: invalid pulse1_delay. ' ...
            'Setting to 3.']);
  tp.pulse1_delay = 3;
end

tp.pulse2_delay = round(tp.pulse2_delay);
if (tp.pulse2_delay < 0) | (tp.pulse2_delay >= tp.num_samples)
  errordlg(['TP: invalid pulse1_delay. ' ...
            'Setting to 3.']);
  tp.pulse2_delay = 3;
end

tp.pulse1_height = 16 * round(tp.pulse1_height/16);
if (tp.pulse1_height < -32768) | (tp.pulse1_height > 32752)
  errordlg(['TP: pulse1_height out of range. ' ...
            'Setting to 3280.']);
  tp.pulse1_height = 16*205;
end

tp.pulse2_height = 16 * round(tp.pulse2_height/16);
if (tp.pulse2_height < -32768) | (tp.pulse2_height > 32752)
  errordlg(['TP: pulse2_height out of range. ' ...
            'Setting to -3280.']);
  tp.pulse2_height = 16*(-205);
end

tp.pulse1_width = round(tp.pulse1_width);
if (tp.pulse1_width < 0) | (tp.pulse1_width >= tp.num_samples)
  errordlg(['TP: invalid pulse1_delay. ' ...
            'Setting to 10.']);
  tp.pulse1_width = 10;
end

tp.pulse2_width = round(tp.pulse2_width);
if (tp.pulse2_width < 0) | (tp.pulse2_width >= tp.num_samples)
  errordlg(['TP: invalid pulse2_delay. ' ...
            'Setting to 10.']);
  tp.pulse2_width = 10;
end

tp.num_stims = round(tp.num_stims);

if (tp.frequency < .1) | (tp.frequency > 10)
  errordlg(['TP: invalid frequency. ' ...
            'Setting to 10.']);
  tp.frequency = 10;
end

tp.lockmode = round(tp.lockmode);
if ~ismember(tp.lockmode,[1 2 3])
  errordlg(['TP: invalid lockmode. ' ...
            'Setting to 1 (locking off).']);
  tp.lockmode = 1;
end

switch tp.lockmode

  case 1
    tp.h1h2_ratio = [];
    tp.w1w2_ratio = [];
    tp.d2w1_ratio = [];

  case 2
    tp.h1h2_ratio = tp.pulse1_height/tp.pulse2_height;
    tp.w1w2_ratio = tp.pulse1_width/tp.pulse2_width;
    tp.d2w1_ratio = tp.pulse2_delay/tp.pulse1_width;

  case 3
    valu = find(tp.h1h2_ratio == [-.25 -.5 -1 -2 -4]);
    if isempty(valu)
      errordlg(['TP: h1h2_ratio not valid in lockmode 3. ' ...
                'Setting to -1.']);
      tp.h1h2_ratio = -1;
    end
    tp.w1w2_ratio = -1/tp.h1h2_ratio;
    valu = find(tp.d2w1_ratio == [.25 .5 1 2 4]);
    if isempty(valu)
      errordlg(['TP: d2w1_ratio not valid in lockmode 3. ' ...
                'Setting to 1.']);
      tp.d2w1_ratio = 1;
    end

    [tp,err] = TPShpLck(tp,'lkw1h1');
    if err
      errordlg(['TP: cannot find an acceptable pre-set ' ...
                'shape in lockmode 3.  Setting to ' ...
                'lockmode 1 (locking off).']);
      tp.lockmode = 1;
    end

end

if ~ismember(tp.silent,[0 1])
  errordlg(['TP: invalid silent flag value. ' ...
            'Setting to 0.']);
  tp.silent = 0;
end

if (tp.silent == 1) & (tp.num_stims < 0)
  errordlg(['TPsw/TPstartstop: cannot run indefinitely in ' ...
            'absence of GUI.  No stimulations will be ' ...
            'sent to the output.']);
  tp.num_stims = 0;
end

if ~ismember(tp.rt,[1 2 3])
  errordlg(['TP: invalid rt. ' ...
            'Setting to 2 (100kOhm,2uA/V).']);
  tp.rt = 2;
end

if ~ismember(tp.np,[1 2 3 4 5 6])
  errordlg(['TP: invalid np. ' ...
            'Setting to 1.']);
  tp.np = 1;
end

% If not running in silent mode, update screen to reflect
% values in tp.

if ~tp.silent

  if isempty(findobj('Tag','TwoPulse'))
    TPscr;
    intrmenu;
  end

  TPNwTxt(tp,100);


  set(findobj('Tag','Rt'),'Value',tp.rt)
  set(findobj('Tag','ShapeLock'),'Value',tp.lockmode)
  switch tp.lockmode

    % locking is off
    case 1
      set(findobj('Tag','h1h2ratio'),'Visible','off')
      set(findobj('Tag','d2w1ratio'),'Visible','off')
      set(findobj('Tag','ShapeLock'), ...
      'BackgroundColor',[.701961 .701961 .701961], ...
      'ForegroundColor',[0 0 0])

    % locking is on - user's shape
    case 2
      set(findobj('Tag','h1h2ratio'),'Visible','off')
      set(findobj('Tag','d2w1ratio'),'Visible','off')
      set(findobj('Tag','ShapeLock'), ...
      'BackgroundColor',[0 0 1],'ForegroundColor',[1 1 1])

    % locking is on - preset shape
    case 3
      set(findobj('Tag','h1h2ratio'),'Visible','on')
      set(findobj('Tag','h1h2ratio','Style','popupmenu'), ...
        'Value',3+log2(-tp.h1h2_ratio));
      set(findobj('Tag','d2w1ratio'),'Visible','on')
      set(findobj('Tag','d2w1ratio','Style','popupmenu'), ...
        'Value',3+log2(tp.d2w1_ratio));
      set(findobj('Tag','ShapeLock'), ...
      'BackgroundColor',[0 0 1],'ForegroundColor',[1 1 1])

  end

  switch sign(tp.num_stims) 

    % finite number of rounds of stimulation
    case {0,1}
      set(findobj('Tag','NumStims'),'Value',1)
      set(findobj('Tag','count'),'Visible','on')

    % infinite number of rounds of stimulation
    case -1
      set(findobj('Tag','NumStims'),'Value',2)
      set(findobj('Tag','count'),'Visible','off')

  end

  set(findobj('Tag','NumPairs'),'Value',tp.np);
  if (tp.np == 1)
    set(findobj('Tag','InterPair'),'Visible','off');
    set(findobj('Tag','InterPairLabel'),'Visible','off');
  else
    set(findobj('Tag','InterPair'),'Visible','on');
    set(findobj('Tag','InterPairLabel'),'Visible','on');
    set(findobj('Tag','InterPair','Style','text'), ...
      'String',num2str(tp.ipd*tp.update_interval));
  end
  TPPltPls(tp);

end

%8/27/97: These calls to DAP board have been moved to TPSttStp.
% Reset DAP board and download routines used by twopulse screen.
%DapRset
%TPDapNit









