function newtp = TPswsl(oldtp)
%TPswsl: lock or unlock twopulse wave shape

% This routine returns the same oldtp structure if
% a pre-set waveform was requested, but could not
% be found.

% WARNING: In the current code, no errors are sent back to the
% calling procedure if a suitable pre-set waveform could
% not be found.

newtp = oldtp;

% If not running in silent mode, get locking parameters from
% screen.
if ~newtp.silent

  % Note that the value of the popupmenu with 'Tag'
  % equal to 'ShapeLock' keeps track of the locking mode.
  % A value of 1 is for no locking, a value of 2 is for
  % locking on the current pulse shape, and a value
  % of 3 is for locking on one of the preset shapes.
  newtp.lockmode = get(findobj('Tag','ShapeLock'),'Value');

  if newtp.lockmode == 3
    newtp.h1h2_ratio = -2 ^ ( -3 + ...
      get(findobj('Tag','h1h2ratio','Style','popupmenu'),'Value') );
    newtp.w1w2_ratio = -1/newtp.h1h2_ratio;
    newtp.d2w1_ratio =  2 ^ ( -3 + ...
      get(findobj('Tag','d2w1ratio','Style','popupmenu'),'Value') );
  end
end

% Perform any needed updates to newtp.
% err will be set to 1 if a suitable waveform could not be found,
% and the routine will retrun the old tp structure.
switch newtp.lockmode

  case 1
    newtp.h1h2_ratio = [];
    newtp.w1w2_ratio = [];
    newtp.d2w1_ratio = [];

  case 2
    newtp.h1h2_ratio = newtp.pulse1_height/newtp.pulse2_height;
    newtp.w1w2_ratio = newtp.pulse1_width/newtp.pulse2_width;
    newtp.d2w1_ratio = newtp.pulse2_delay/newtp.pulse1_width;

  case 3
    [newtp,err] = TPShpLck(newtp,'lkw1h1');
    if err
      newtp = oldtp;
    end
end


% Perform any relevant updates to screen.

if ~newtp.silent

  TPPltPls(newtp)
  TPNwTxt(newtp,100)

  set(findobj('Tag','ShapeLock'),'Value',newtp.lockmode)

  switch newtp.lockmode

    % locking is off
    case 1
      set(findobj('Tag','h1h2ratio'),'Visible','off')
      set(findobj('Tag','d2w1ratio'),'Visible','off')
      set(findobj('Tag','ShapeLock'), ...
      'BackgroundColor',[.701961 .701961 .701961], ...
      'ForegroundColor',[0 0 0])
 
    % locking is on - user's shape
    case 2
      set(findobj('Tag','h1h2ratio'),'Visible','off')
      set(findobj('Tag','d2w1ratio'),'Visible','off')
      set(findobj('Tag','ShapeLock'), ...
      'BackgroundColor',[0 0 1],'ForegroundColor',[1 1 1])
   
    % locking is on - preset shape
    case 3
      set(findobj('Tag','h1h2ratio'),'Visible','on')
      set(findobj('Tag','h1h2ratio','Style','popupmenu'), ...
        'Value',3+log2(-newtp.h1h2_ratio));
      set(findobj('Tag','d2w1ratio'),'Visible','on')
      set(findobj('Tag','d2w1ratio','Style','popupmenu'), ...
        'Value',3+log2(newtp.d2w1_ratio));
      set(findobj('Tag','ShapeLock'), ...
      'BackgroundColor',[0 0 1],'ForegroundColor',[1 1 1])
  
  end

end
