/*
  Copyright (c) 1993, Microstar Laboratories, Inc.
  All rights reserved.
  Confidential source code.       
*/

/* This is the BiFIFO header file. It contains AM4701 register addresses, 
   message definitions, etc. 
*/

#include "dapio.h"

#define BfData        0x04       /* BiFIFO data port offset */
#define BfControl     0x06       /* BiFIFO control port offset */
/* #define CtrlPort DapAddr+BfControl */  /* Moved to daccel.c */
/* #define DataPort DapAddr+BfData    */

#define BfMaskAll   0x0000
#define BfMesInt    0x0004       /* mailbox interrupt bit */
#define BfFullInt   0x0040       /* FIFO full interrupt bit */

#define FIFOSize     1024        /* physical FIFO size 1024 bytes */
#define FIFOHdrSize     4        /* 2 bytes size and 2 bytes pipe number */
#define FIFODataSize 1024-FIFOHdrSize
#define BfPtrReg       0x0       /* Pointer register address */
#define BfStatus       0x0       /* Status register address */
#define BfCommand   0x0101       /* Command register address */
#define BfMask      0x0202       /* Mask register address */
#define BfOutMb     0x0404       /* 16-bit outbound register address */
#define BfOutMbL      0x04       /* address of the lower outbound mailbox */
#define BfOutMbH    0x0400       /* address of the higher outbound mailbox */
#define BfInMb      0x0606       /* address of 16 bit inbound mailbox */
#define BfReadPtr   0x0606       /* address of the 16 bit read pointer */
#define BfWritePtr  0x0707       /* address of the 16 bit write pointer */

/* Return code for messages */

#define Sending       0x01
#define ReturnOk      0x02
#define ReturnCancel  0x04
#define Dummy         0x08
#define HiDummy     0x0800         /* High Order DUMMY message */
#define Reply         0x40
#define Ready         0x80
#define ReadyMask     0x3F         /* Reply Message pipe number mask */

/* BiFIFO command register bit masks */
#define BfBypass        0x2020
#define BfShiftStatus   0x4040
#define BfMR            0x8080

#define MaxQueueDepth 130

typedef  struct {
    int  iHead;          /* index of the message queue head entry */
    int  iTail;          /* index of the message queue tail entry */
    word bDoneSent;      /* flag, true if a message that does not require a 
                            reply has last been sent. */
    word bAlwaysReply;   /* flag, set if a return message is required */
    byte aMessages[MaxQueueDepth];   /* phsycal message queue */   
} QueueType;

/* structures for reading and writing the BiFIFO through accel_ioctl */
typedef struct BiFIFOStruct{
  word Ofs;
  word Val;
} BiFIFO_t;

/* macro definitions */

#define getData() INPW(DataPort)
#define putData(wData) OUTW(DataPort,wData)
#define obMbBusy ((byte) readReg(BfOutMbL)!=0)
#define mesQEmpty (mesQ.iHead == mesQ.iTail)
#define getStatus() readReg(BfStatus)
#define sendMes(wMessage) writeReg(BfOutMbL,wMessage)
#define sendMesH(wMessage) writeReg(BfOutMbH,wMessage)
#define resetRead() writeReg(BfReadPtr,BfReadPtr)
#define resetWrite() writeReg(BfWritePtr,BfWritePtr)
#define disableBfInt(intMask) writeReg(BfMask,intMask) 
#define enableBfInt(intUnMask) writeReg(BfMask,intUnMask) 

/* function prototype declarations */

word readReg (word);
void writeReg (word, word);
byte getMessage(void);
void queueMes(byte);
void queueMesH(byte);
void flushMes(void);
