/*
  Copyright (c) 1993, Microstar Laboratories, Inc.
  All rights reserved.
  Confidential source code.       
*/

/* This is the header file that contains definitions of pipe structures
   and constants.
*/

/* A custom driver may want to define the following two values dynamically */

#define PipeMaxSize 2048  /* 1024 is the minimum value for this constant */
#define MaxNumberPipes 2  /* one text, pipe 0, and one binary, pipe 1 */

typedef struct
{ 
    volatile word wCount;  /*  number of values in the pipe */
    word eType;            /* type of the pipe, input/output */
    word wPipeNum;         /* com pipe number */
    word wWidth;           /* width of the pipe in bytes */
    word wMaxSize;         /* maximum size of the pipe */
    word ofFirst;          /* offset of first value */
    word ofLast;           /* offset of the last value */
    word ofOldFirst;       /* stores the offset to the old head */
    word wNumRel;          /* number of bytes to be released. */
    word wBlockItems;      /* number of items in a block */
    word wNBlocks;         /* max number of blocks that fit in a FIFO */
    word eStatus;          /* status of the pipe */
    byte *uBuffer;         /* the physical buffer */
} ComPipe;

#define InputPipe   0
#define OutputPipe  1

/* Com pipe status flag */

#define Done           0  /* All transactions are done */
#define ReadyToSend    1  /* there are data in the output com pipe ready to */
                          /* transfer */
#define BeingSent      2  /* portion of the data in the output com pipe are */
                          /* being transmitted */
#define Paused         3  /* a send request has benn turned down by the */
                          /* receiver port because of lack of space */
#define ReadyToReceive 4  /* the input com pipe has space for at least one */
                          /* block of FIFO data (510) words */
#define Restarting     5  /* has turned down a SEND request; once the pipe */
                          /* has space, this port should initiate a restart */

/* PIPE function prototypes */

void getBPipeInt(ComPipe *, byte *, word);
void releasePipe(ComPipe *);
void putBPipeInt(ComPipe *, byte *, word);
word getBPipe(ComPipe *, byte *, word);
void putBPipe(ComPipe *, byte *, word);
