#include <stdio.h>
#include <sys/times.h>
#include <sys/types.h>
#include <sys/file.h>
#include <errno.h>
#include "mex.h"
#include "intrfc.h"
#include "dapio.c"
#define SetBit12 (1 << 12) |
#define SetBit13 (1 << 13) |
#define SetBit14 (1 << 14) |
#define SetBit15 (1 << 15) |

void mexFunction(
   int nlhs, mxArray *plhs[],
   int nrhs, const mxArray *prhs[])
   {
   int mrows,ncols;
   short FromDap[200000];
   double *ToMatlab;
   int i,j;
   int total,BytesAvail;
   clock_t t;
   struct tms buf;
   char dapline[80];
   char DapFileName[80];
   char channel[2];

   /* Check for proper number of arguments */
   if (nrhs != 1) {
      mexErrMsgTxt("samplong usage: samplong('A-H')");
   }

   /* The input must be a noncomplex 1 by 1 vector */
   mrows = mxGetM(prhs[0]);
   ncols = mxGetN(prhs[0]);

   if ( !mxIsChar(prhs[0]) ||
        !(mrows==1 && ncols==1) ) {
      mexErrMsgTxt("samplong usage: samplong('A-H')");
   }

   /* Get the channel letter */
   mxGetString(prhs[0],channel,2);

    /* Redirect ctrl-c so that MEX file can close DAP channels
      before exiting. */
   mysig();

   /* Open handles to DAP text and binary communication pipes */
   if ((fdDapTxt=open("/dev/accel0",O_RDWR)) <= 0)
     { printf("Error opening accel0, errno=%d\n",errno); return; }
   if ((fdDapBin=open("/dev/accel1",O_RDWR)) <= 0)
     { printf("Error opening accel1, errno=%d\n",errno); return; }

   /* Flush communication channels. */
   DAPFlush(fdDapBin);
   DAPFlush(fdDapTxt);

   /* Send configuration file to DAP */
   switch(channel[0]){
   case 'A': case 'a':
     strcat(strcpy(DapFileName,DAP_PATH),"samplonga.dap");
     break;
   case 'B': case 'b':
     strcat(strcpy(DapFileName,DAP_PATH),"samplongb.dap");
     break;
   case 'C': case 'c':
     strcat(strcpy(DapFileName,DAP_PATH),"samplongc.dap");
     break;
   case 'D': case 'd':
     strcat(strcpy(DapFileName,DAP_PATH),"samplongd.dap");
     break;
   case 'E': case 'e':
     strcat(strcpy(DapFileName,DAP_PATH),"samplonge.dap");
     break;
   case 'F': case 'f':
     strcat(strcpy(DapFileName,DAP_PATH),"samplongf.dap");
     break;
   case 'G': case 'g':
     strcat(strcpy(DapFileName,DAP_PATH),"samplongg.dap");
     break;
   case 'H': case 'h':
     strcat(strcpy(DapFileName,DAP_PATH),"samplongh.dap");
     break;
   default:
     close(fdDapTxt);
     close(fdDapBin);
     mexErrMsgTxt("samplong usage: samplong('A-H')");
   }
   DAPSendFile(fdDapTxt,DapFileName);

   /* Pause 100ms while data is sent to DAP */
   t = times(&buf);
   while ((times(&buf)-t) < 1) {}

   /* Create an array to return data to MATLAB */
   plhs[0] = mxCreateDoubleMatrix(1,200000,mxREAL);
   ToMatlab = mxGetPr(plhs[0]);

   /* Turn LED on */
   DAPSendLine(fdDapTxt,"let v1=16384\r");
   
   /* Pause 3 sec*/
   t = times(&buf);
   while ((times(&buf)-t) < 300) {}

   /* Turn LED off */
   DAPSendLine(fdDapTxt,"let v1=0\r");

   /* Pause 100ms while data is sent to DAP */
   t = times(&buf);
   while ((times(&buf)-t) < 1) {}

   /* Wait for data and get it */
   for (i=0;i<400;i++)
     {
     t = times(&buf);
     while (DAPGetAvail(fdDapBin) < 1000) {
       if ((times(&buf)-t) > 1000) {break;}}
      
     if (DAPGetAvail(fdDapBin) >= 1000)  
       read(fdDapBin,(FromDap+(i*500)),1000);
     }

   /* Copy data to output array */
   for (i=0;i<200000;i++)
     ToMatlab[i] = (double) FromDap[i];
  
   /* Stop DAP script. */
   DAPSendLine(fdDapTxt,"stop recorda,recordb\r");

   /* close handles */
   close(fdDapTxt);
   close(fdDapBin);

   /* Restore original ctrl-c handler. */
   restoresig();

   }








