#include <stdio.h>
#include <sys/times.h>
#include <sys/types.h>
#include <sys/file.h>
#include <errno.h>
#include "mex.h"
#include "intrfc.h"
#include "dapio.c"

void mexFunction(
   int nlhs, mxArray *plhs[],
   int nrhs, const mxArray *prhs[])
   {
   short DapData[46];
   int i,j;
   struct tms buf;
   clock_t t;
   unsigned int SpikeTime;
   unsigned int NumChanSpikes[8];
   double *ToMatlab;

   /* Redirect ctrl-c so that MEX file can close DAP channels
      before exiting. */
   mysig();

   for (i=0;i<8;i++)
     NumChanSpikes[i] = 0;

   /* Create an array to return spike data to MATLAB */
   plhs[0] = mxCreateDoubleMatrix(1,8*22*MAX_SPIKES_PER_CHANNEL,mxREAL);
   ToMatlab = mxGetPr(plhs[0]);

   /* Open handles to DAP text and binary communication pipes */
   if ((fdDapTxt=open("/dev/accel0",O_RDWR)) <= 0)
     { printf("Error opening accel0, errno=%d\n",errno); return; }
   if ((fdDapBin=open("/dev/accel1",O_RDWR)) <= 0)
     { printf("Error opening accel1, errno=%d\n",errno); return; }

   /* Empty pipes on Dap board */
   DAPSendLine(fdDapTxt,"start cleanhouse\r");
   t = times(&buf);
   while ( (times(&buf)-t) < 10 );
   DAPSendLine(fdDapTxt,"stop cleanhouse\r");

   /* Flush data pipe */
   DAPFlush(fdDapBin);

   /* Wait a brief interval */
   t = times(&buf);
   while ( (times(&buf)-t) < 10 );

   /* Start DAP script */
   DAPSendLine(fdDapTxt,"start spikera,spikerb\r");

   /* Collect Data for 11 sec. */
   i = 0;
   t = times(&buf);
   while ( (times(&buf)-t) < 1100 ) {
     if (DAPGetAvail(fdDapBin) >= 46) {
       read(fdDapBin,DapData,46);
       if (NumChanSpikes[DapData[0]] < MAX_SPIKES_PER_CHANNEL) {
         ToMatlab[i] = (double) DapData[0];
         SpikeTime = (unsigned int) ((unsigned short) DapData[2]) << 16;
         SpikeTime = SpikeTime + (unsigned int) ((unsigned short) DapData[1]);
         ToMatlab[i+1] = (double) SpikeTime;
         for (j=3;j<23;j++)
           ToMatlab[i+j-1] = DapData[j];
         NumChanSpikes[DapData[0]]++;
         i += 22;}}
   }


   /* Wait a brief interval */
   t = times(&buf);
   while ( (times(&buf)-t) < 10 );

   /* close handles */
   close(fdDapTxt);
   close(fdDapBin);

   /* Restore original ctrl-c handler. */
   restoresig();

   }








